/*========================== begin_copyright_notice ============================

Copyright (C) 2020-2021 Intel Corporation

SPDX-License-Identifier: MIT

============================= end_copyright_notice ===========================*/

#ifndef IGCLLVM_IR_PATTERNMATCH_H
#define IGCLLVM_IR_PATTERNMATCH_H

#include "llvm/Config/llvm-config.h"
#include "llvm/IR/PatternMatch.h"

namespace llvm {
namespace PatternMatch {} // namespace PatternMatch
} // namespace llvm

#endif
